FlutterPwValidatorStrings class

Strings hold constant strings used across the package

Constructors

FlutterPwValidatorStrings()

Properties

atLeast → String
final
hashCode → int
The hash code for this object.
no setterinherited
lowercaseLetters → String
final
normalLetters → String
final
numericCharacters → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specialCharacters → String
final
uppercaseLetters → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited