Validator class

Validator class hold the RegExp for requested validation

Constructors

Validator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasMinLength(String password, int minLength) → bool
Checks if password has minLength
hasMinLowercase(String password, int lowercaseCount) → bool
Checks if password has at least lowercaseCount lowercase letter matches
hasMinNormalChar(String password, int normalCount) → bool
Checks if password has at least normal char letter matches
hasMinNumericChar(String password, int numericCount) → bool
Checks if password has at least numericCount numeric character matches
hasMinSpecialChar(String password, int specialCount) → bool
hasMinUppercase(String password, int uppercaseCount) → bool
Checks if password has at least uppercaseCount uppercase letter matches
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited